summaryrefslogtreecommitdiffstats
path: root/amarok/src/playerwindow.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:29:16 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:29:16 -0600
commit2d3d921590b44ae1e8864104f3e36d022bec0308 (patch)
treea3c17b3a19ac6a26cddd8c0705bf55ff8f46665a /amarok/src/playerwindow.cpp
parent6fd8dcd450a39343afe010a50dd0956eb4184540 (diff)
downloadamarok-2d3d921590b44ae1e8864104f3e36d022bec0308.tar.gz
amarok-2d3d921590b44ae1e8864104f3e36d022bec0308.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'amarok/src/playerwindow.cpp')
-rw-r--r--amarok/src/playerwindow.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/amarok/src/playerwindow.cpp b/amarok/src/playerwindow.cpp
index 63ebd843..9c061cbd 100644
--- a/amarok/src/playerwindow.cpp
+++ b/amarok/src/playerwindow.cpp
@@ -54,10 +54,10 @@ namespace Amarok
TQPixmap getPNG( const TQString &filename )
{
- TQString file = !filename.tqendsWith( ".png", false ) ? "amarok/images/%1.png" : "amarok/images/%1";
+ TQString file = !filename.endsWith( ".png", false ) ? "amarok/images/%1.png" : "amarok/images/%1";
TQPixmap pix;
- TQImage img( locate( "data", file.tqarg( filename ) ), "PNG" );
+ TQImage img( locate( "data", file.arg( filename ) ), "PNG" );
if (TQPaintDevice::x11AppDepth() == 32) pix.convertFromImage(KImageEffect::convertToPremultipliedAlpha( img ));
else pix.convertFromImage( img );
return pix;
@@ -65,10 +65,10 @@ namespace Amarok
TQPixmap getJPG( const TQString &filename )
{
- TQString file = !filename.tqendsWith( ".jpg", false ) ? "amarok/images/%1.jpg" : "amarok/images/%1";
+ TQString file = !filename.endsWith( ".jpg", false ) ? "amarok/images/%1.jpg" : "amarok/images/%1";
TQPixmap pix;
- TQImage img( locate( "data", TQString( "amarok/images/%1.jpg" ).tqarg( filename ) ), "JPEG" );
+ TQImage img( locate( "data", TQString( "amarok/images/%1.jpg" ).arg( filename ) ), "JPEG" );
if (TQPaintDevice::x11AppDepth() == 32) pix.convertFromImage(KImageEffect::convertToPremultipliedAlpha( img ));
else pix.convertFromImage( img );
return pix;
@@ -100,7 +100,7 @@ PlayerWidget::PlayerWidget( TQWidget *parent, const char *name, bool enablePlayl
, m_pAnalyzer( 0 )
{
//the createWidget template function is used here
//createWidget just creates a widget which has it's tqgeometry set too
// Sets caption and icon correctly (needed e.g. for GNOME)
kapp->setTopWidget( this );
@@ -127,7 +127,7 @@ PlayerWidget::PlayerWidget( TQWidget *parent, const char *name, bool enablePlayl
setFont( font );
{ //<NavButtons>
- //NOTE we use a tqlayout for the buttons so resizing will be possible
+ //NOTE we use a layout for the buttons so resizing will be possible
m_pFrameButtons = createWidget<TQHBox>( TQRect(0, 118, 311, 22), this );
KActionCollection *ac =Amarok::actionCollection();
@@ -140,7 +140,7 @@ PlayerWidget::PlayerWidget( TQWidget *parent, const char *name, bool enablePlayl
new NavButton( m_pFrameButtons, "next", ac->action( "next" ) );
KPushButton *switchView = new KPushButton( KGuiItem( "", "mini_dock" ), m_pFrameButtons );
- switchView->tqsetSizePolicy( TQSizePolicy::Maximum, TQSizePolicy::Preferred ); // too big!
+ switchView->setSizePolicy( TQSizePolicy::Maximum, TQSizePolicy::Preferred ); // too big!
switchView->setFocusPolicy( TQ_NoFocus );
connect( switchView, TQT_SIGNAL( clicked() ), TQT_SLOT( toggleView() ) );
@@ -381,7 +381,7 @@ void PlayerWidget::engineNewMetaData( const MetaBundle &bundle, bool )
if( m_rateString.isEmpty() )
m_rateString = Hz;
else
- m_rateString = i18n("%1 kBit - %2").tqarg( m_rateString, Hz );
+ m_rateString = i18n("%1 kBit - %2").arg( m_rateString, Hz );
}
TQStringList list( bundle.prettyTitle() );
@@ -774,15 +774,15 @@ void PlayerWidget::mousePressEvent( TQMouseEvent *e )
{
//Amarok::Menu::instance()->exec( e->globalPos() );
}
- else if ( m_pAnalyzer->tqgeometry().contains( e->pos() ) )
+ else if ( m_pAnalyzer->geometry().contains( e->pos() ) )
{
createAnalyzer( e->state() & TQt::ControlButton ? -1 : +1 );
}
else
{
TQRect
- rect = m_pTimeLabel->tqgeometry();
- rect |= m_pTimeSign->tqgeometry();
+ rect = m_pTimeLabel->geometry();
+ rect |= m_pTimeSign->geometry();
if ( rect.contains( e->pos() ) )
{
@@ -100,7 +100,7 @@ PlayerWidget::PlayerWidget( TQWidget *parent, const char *name, bool enablePlayl
{
//the createWidget template function is used here
- //createWidget just creates a widget which has it's tqgeometry set too
+ //createWidget just creates a widget which has it's geometry set too
// Sets caption and icon correctly (needed e.g. for GNOME)
kapp->setTopWidget( this );